OAuth clients

Create and manage the configuration of OAuth clients in your tenant.

List OAuth clients

Retrieve all OAuth clients.

Facts

Rate limit Tier 1 (1000 requests per minute)

Query Parameters

  • filter string

    The filter query that should be used to filter the list of oauth clients. The filter syntax is defined in RFC 7644. Valid attributes for filtering are clientId, clientName, appType, tenantId, and createdByType.

  • limit number

    The number of OAuth client entries to retrieve.

  • next string

    The next page cursor

  • prev string

    The previous page cursor

  • sort string

    The attribute to sort by, beginning with + for ascending and - for descending. Valid attributes for sorting are clientId, clientName, appType, tenantId, createdAt, updatedAt.

    Can be one of: "+clientId""-clientId""+clientName""-clientName""+appType""-appType""+tenantId""-tenantId""+createdAt""-createdAt""+updatedAt""-updatedAt"

  • totalResults boolean

    Boolean query parameter that determines if the total count of results should be included in the response. If true, the response includes the total number of results in the totalResults field. If false or not included in the query, totalResults will be excluded from the response.

Responses

200

OK

  • application/json object
    One of:
    • OAuthClientAdminListResponse object

      Response schema for listing OAuth clients as an admin user

      Show OAuthClientAdminListResponse properties
      • data array of objects
        Required

        Schema for a OAuth client when listing as an admin user

        Show data properties
        • jwksUri string

          URI of the JSON Web Key Set (JWKS) for the client

        • clientId string
          Required

          Client application id

        • publicKeys array of objects

          List of public keys for JWT authentication

          Show publicKeys properties
          • e string

            Exponent for RSA keys

          • n string

            Modulus for RSA keys

          • x string

            X coordinate for EC keys

          • y string

            Y coordinate for EC keys

          • alg string
            Required

            Algorithm intended for use with the key

            Can be one of: "RS256""RS512""ES384"

          • crv string

            Curve for EC keys

          • kid string
            Required

            Key ID

          • kty string
            Required

            Key type (e.g., RSA, EC)

            Can be one of: "RSA""EC"

          • use string
            Required

            Intended use of the key (typically "sig" for signature)

            Can be one of: "sig"

        • redirectUris array of strings

          List of allowed redirect URIs for login

        • clientSecrets array of objects

          Hints of any client application secrets

          Show clientSecrets properties
          • hint string
            Required

            Hint of a client application secret

          • createdAt string

            The timestamp for when the client-secret record was created.

          • createdBy string

            The identifier for the user that created the client-secret record.

        • allowedOrigins array of strings

          List of allowed origins for client

        • connectionConfig object

          Optional settings for configuring the client connection.

          Show connectionConfig properties
          • status string

            Status

          • consentMethod string
            Required

            Specifies the consent method for the connection.

            Can be one of: "required""trusted"

          • deletedByOwner boolean

            OAuth client has been deleted by owning tenant, only applies for published clients.

        • allowedAuthMethods array of strings

          List of allowed authentication methods for the client

          Values may be any of: "client_secret""private_key_jwt"

        • appType string
          Required

          Application type

          Can be one of: "web""native""spa""anonymous-embed"

        • logoUri string

          URI for logo of client

        • clientUri string

          URI for homepage of client

        • createdAt string
          Required

          The timestamp for when the oauth-clients record was created.

        • deletedAt string

          The timestamp for when the oauth-clients record was deleted.

        • updatedAt string

          The timestamp for when the oauth-clients record was updated.

        • clientName string
          Required

          Client application name

        • disableTag string

          Is set if client disabled

        • description string

          Client description

        • publishedAt string

          The timestamp which is set, if the client is published.

        • allowedScopes array of strings

          List of allowed scopes for this client. For a full list of scopes see qlik.dev/authenticate/oauth/scopes/.

        • createdByType string

          The type of caller that created this client. Possible values are user, service, and dcr for Dynamic Client Registration.

        • allowedGrantTypes array of strings

          Allowed grant types, only for use with appType: 'web'

          Values may be any of: "client_credentials""urn:qlik:oauth:user-impersonation"

      • links object
        Required
        Show links properties
        • next object
          Show next properties
          • href string
            Required

            URL that defines the resource

        • prev object
          Show prev properties
          • href string
            Required

            URL that defines the resource

        • self object
          Show self properties
          • href string
            Required

            URL that defines the resource

      • totalResults integer

        Total number of oauth clients, included only if totalResults query parameter is set to true.

    • OAuthClientListResponse object

      Response schema for listing OAuth clients

      Show OAuthClientListResponse properties
      • data array of objects
        Required

        Response schema for reading an OAuth client

        Show data properties
        • clientId string
          Required

          Client application id

        • appType string
          Required

          Application type

          Can be one of: "web""native""spa""anonymous-embed"

        • jwksUri string

          URI of the JSON Web Key Set (JWKS) for the client

        • logoUri string

          URI for logo of client

        • clientUri string

          URI for homepage of client

        • createdAt string
          Required

          The timestamp for when the oauth-clients record was created.

        • deletedAt string

          The timestamp for when the oauth-clients record was deleted.

        • updatedAt string

          The timestamp for when the oauth-clients record was updated.

        • clientName string
          Required

          Client application name

        • disableTag string

          Is set if client disabled

        • publicKeys array of objects

          List of public keys for JWT authentication

          Show publicKeys properties
          • e string

            Exponent for RSA keys

          • n string

            Modulus for RSA keys

          • x string

            X coordinate for EC keys

          • y string

            Y coordinate for EC keys

          • alg string
            Required

            Algorithm intended for use with the key

            Can be one of: "RS256""RS512""ES384"

          • crv string

            Curve for EC keys

          • kid string
            Required

            Key ID

          • kty string
            Required

            Key type (e.g., RSA, EC)

            Can be one of: "RSA""EC"

          • use string
            Required

            Intended use of the key (typically "sig" for signature)

            Can be one of: "sig"

        • description string

          Client description

        • publishedAt string

          The timestamp which is set, if the client is published.

        • allowedScopes array of strings

          List of allowed scopes for this client. For a full list of scopes see qlik.dev/authenticate/oauth/scopes/.

        • clientSecrets array of objects

          Hints of any client application secrets

          Show clientSecrets properties
          • hint string
            Required

            Hint of a client application secret

          • createdAt string

            The timestamp for when the client-secret record was created.

          • createdBy string

            The identifier for the user that created the client-secret record.

        • createdByType string

          The type of caller that created this client. Possible values are user, service, and dcr for Dynamic Client Registration.

        • connectionConfig object

          Optional settings for configuring the client connection.

          Show connectionConfig properties
          • consentMethod string

            Specifies the consent method for the connection.

            Can be one of: "required""trusted"

        • allowedGrantTypes array of strings

          Allowed grant types, only for use with appType: 'web'

          Values may be any of: "client_credentials""urn:qlik:oauth:user-impersonation"

        • allowedAuthMethods array of strings

          List of allowed authentication methods for the client

          Values may be any of: "client_secret""private_key_jwt"

      • links object
        Required
        Show links properties
        • next object
          Show next properties
          • href string
            Required

            URL that defines the resource

        • prev object
          Show prev properties
          • href string
            Required

            URL that defines the resource

        • self object
          Show self properties
          • href string
            Required

            URL that defines the resource

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

GET /api/v1/oauth-clients
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.getOAuthClients({})
qlik oauth-client ls
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients" \
-H "Authorization: Bearer <access_token>"

Example Response

{
"data": [
{
"appType": "web",
"jwksUri": "https://example.com/.well-known/jwks.json",
"logoUri": "string",
"clientUri": "string",
"createdAt": "2018-10-30T07:06:22Z",
"deletedAt": "2018-10-30T07:06:22Z",
"updatedAt": "2018-10-30T07:06:22Z",
"clientName": "string",
"disableTag": "string",
"publicKeys": [
{
"e": "AQAB",
"n": "0vx7agoebGcQSuuPiLJXZptN9nndrQmbXEps2aiAFbWhM78LhWx",
"x": "WKn-ZIGevcwGIyyrzFoZNBdaq9_TsqzGl96oc0CWuis",
"y": "y77t-RvAHRKTsSGdIYUfweuOvwrvDD-Q3Hv5J0fSKbE",
"alg": "RS256",
"crv": "P-384",
"kid": "key-1",
"kty": "RSA",
"use": "sig"
}
],
"description": "string",
"publishedAt": "2018-10-30T07:06:22Z",
"allowedScopes": [
"string"
],
"clientSecrets": [
{
"hint": "string",
"createdAt": "2018-10-30T07:06:22Z",
"createdBy": "string"
}
],
"createdByType": "string",
"connectionConfig": {
"status": "string",
"consentMethod": "string",
"deletedByOwner": true
},
"allowedGrantTypes": [
"client_credentials"
],
"allowedAuthMethods": [
"client_secret"
],
"clientId": "string",
"redirectUris": [
"string"
],
"allowedOrigins": [
"string"
]
}
],
"links": {
"next": {
"href": "string"
},
"prev": {
"href": "string"
},
"self": {
"href": "string"
}
},
"totalResults": 42
}

Create an OAuth client

Create a new OAuth client. Requires TenantAdmin role when created in-tenant. appType cannot be changed after creation. Consent method and published state can be changed after creation. For supported appType, use PATCH /oauth-clients/{id}/connection-configs/me to change consent method, and POST /oauth-clients/{id}/actions/publish to change the client to published after creation.

Facts

Rate limit Tier 2 (100 requests per minute)

Request Body

Required
  • application/json object

    Request schema for OAuth client creation

    Show application/json properties
    • appType string
      Required

      Application type

      Can be one of: "web""native""spa""anonymous-embed"

    • jwksUri string

      URI of the JSON Web Key Set (JWKS) for the client

    • logoUri string

      URI for logo of client

    • clientUri string

      URI for homepage of client

    • clientName string
      Required

      Client application name

    • publicKeys array of objects

      List of public keys for JWT authentication (required when using private_key_jwt)

      Show publicKeys properties
      • e string

        Exponent for RSA keys

      • n string

        Modulus for RSA keys

      • x string

        X coordinate for EC keys

      • y string

        Y coordinate for EC keys

      • alg string
        Required

        Algorithm intended for use with the key

        Can be one of: "RS256""RS512""ES384"

      • crv string

        Curve for EC keys

      • kid string
        Required

        Key ID

      • kty string
        Required

        Key type (e.g., RSA, EC)

        Can be one of: "RSA""EC"

      • use string
        Required

        Intended use of the key (typically "sig" for signature)

        Can be one of: "sig"

    • description string

      Client description

    • redirectUris array of strings

      List of allowed redirect URIs for login

    • allowedScopes array of strings

      List of allowed scopes for this client. For a full list of scopes see qlik.dev/authenticate/oauth/scopes/.

    • allowedOrigins array of strings

      List of allowed origins for this client, only available with SPA application type

    • connectionConfig object

      Optional settings for configuring the client connection.

      Show connectionConfig properties
      • consentMethod string

        Specifies the consent method for the connection. The only allowed value is "trusted."

        Can be one of: "trusted"

    • allowedGrantTypes array of strings

      Allowed grant types, only for use with appType: 'web'

      Values may be any of: "client_credentials""urn:qlik:oauth:user-impersonation"

    • allowedAuthMethods array of strings

      List of allowed authentication methods for the client

      Values may be any of: "client_secret""private_key_jwt"

Responses

201

Created

  • application/json object

    Response schema for OAuth client creation

    Show application/json properties
    • clientId string
      Required

      Client application id

    • publicKeys array of objects

      List of public keys for JWT authentication

      Show publicKeys properties
      • e string

        Exponent for RSA keys

      • n string

        Modulus for RSA keys

      • x string

        X coordinate for EC keys

      • y string

        Y coordinate for EC keys

      • alg string
        Required

        Algorithm intended for use with the key

        Can be one of: "RS256""RS512""ES384"

      • crv string

        Curve for EC keys

      • kid string
        Required

        Key ID

      • kty string
        Required

        Key type (e.g., RSA, EC)

        Can be one of: "RSA""EC"

      • use string
        Required

        Intended use of the key (typically "sig" for signature)

        Can be one of: "sig"

    • clientSecret string
      Required

      Client application secret

    • redirectUris array of strings

      List of allowed redirect URIs for login

    • allowedOrigins array of strings

      List of allowed redirect URIs for login

    • allowedAuthMethods array of strings

      List of allowed authentication methods for the client

      Values may be any of: "client_secret""private_key_jwt"

    • appType string
      Required

      Application type

      Can be one of: "web""native""spa""anonymous-embed"

    • jwksUri string

      URI of the JSON Web Key Set (JWKS) for the client

    • logoUri string

      URI for logo of client

    • clientUri string

      URI for homepage of client

    • createdAt string
      Required

      The timestamp for when the oauth-clients record was created.

    • deletedAt string

      The timestamp for when the oauth-clients record was deleted.

    • updatedAt string

      The timestamp for when the oauth-clients record was updated.

    • clientName string
      Required

      Client application name

    • disableTag string

      Is set if client disabled

    • description string

      Client description

    • publishedAt string

      The timestamp which is set, if the client is published.

    • allowedScopes array of strings

      List of allowed scopes for this client. For a full list of scopes see qlik.dev/authenticate/oauth/scopes/.

    • clientSecrets array of objects

      Hints of any client application secrets

      Show clientSecrets properties
      • hint string
        Required

        Hint of a client application secret

      • createdAt string

        The timestamp for when the client-secret record was created.

      • createdBy string

        The identifier for the user that created the client-secret record.

    • createdByType string

      The type of caller that created this client. Possible values are user, service, and dcr for Dynamic Client Registration.

    • connectionConfig object

      Optional settings for configuring the client connection.

      Show connectionConfig properties
      • consentMethod string

        Specifies the consent method for the connection.

        Can be one of: "required""trusted"

    • allowedGrantTypes array of strings

      Allowed grant types, only for use with appType: 'web'

      Values may be any of: "client_credentials""urn:qlik:oauth:user-impersonation"

400

Bad Request

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

POST /api/v1/oauth-clients
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.createOAuthClient({
allowedAuthMethods: ['client_secret'],
allowedGrantTypes: ['client_credentials'],
allowedOrigins: ['string'],
allowedScopes: ['string'],
appType: 'web',
clientName: 'string',
clientUri: 'string',
connectionConfig: { consentMethod: 'trusted' },
description: 'string',
jwksUri:
'https://example.com/.well-known/jwks.json',
logoUri: 'string',
publicKeys: [
{
alg: 'RS256',
crv: 'P-384',
e: 'AQAB',
kid: 'key-1',
kty: 'RSA',
n: '0vx7agoebGcQSuuPiLJXZptN9nndrQmbXEps2aiAFbWhM78LhWx',
use: 'sig',
x: 'WKn-ZIGevcwGIyyrzFoZNBdaq9_TsqzGl96oc0CWuis',
y: 'y77t-RvAHRKTsSGdIYUfweuOvwrvDD-Q3Hv5J0fSKbE',
},
],
redirectUris: ['string'],
})
qlik oauth-client create \
--appType 'web' \
--clientName 'string' \
--publicKeys-alg '' \
--publicKeys-kid '' \
--publicKeys-kty '' \
--publicKeys-use ''
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients" \
-X POST \
-H "Content-type: application/json" \
-H "Authorization: Bearer <access_token>" \
-d '{"appType":"web","jwksUri":"https://example.com/.well-known/jwks.json","logoUri":"string","clientUri":"string","clientName":"string","publicKeys":[{"e":"AQAB","n":"0vx7agoebGcQSuuPiLJXZptN9nndrQmbXEps2aiAFbWhM78LhWx","x":"WKn-ZIGevcwGIyyrzFoZNBdaq9_TsqzGl96oc0CWuis","y":"y77t-RvAHRKTsSGdIYUfweuOvwrvDD-Q3Hv5J0fSKbE","alg":"RS256","crv":"P-384","kid":"key-1","kty":"RSA","use":"sig"}],"description":"string","redirectUris":["string"],"allowedScopes":["string"],"allowedOrigins":["string"],"connectionConfig":{"consentMethod":"trusted"},"allowedGrantTypes":["client_credentials"],"allowedAuthMethods":["client_secret"]}'

Example Response

{
"appType": "web",
"jwksUri": "https://example.com/.well-known/jwks.json",
"logoUri": "string",
"clientUri": "string",
"createdAt": "2018-10-30T07:06:22Z",
"deletedAt": "2018-10-30T07:06:22Z",
"updatedAt": "2018-10-30T07:06:22Z",
"clientName": "string",
"disableTag": "string",
"publicKeys": [
{
"e": "AQAB",
"n": "0vx7agoebGcQSuuPiLJXZptN9nndrQmbXEps2aiAFbWhM78LhWx",
"x": "WKn-ZIGevcwGIyyrzFoZNBdaq9_TsqzGl96oc0CWuis",
"y": "y77t-RvAHRKTsSGdIYUfweuOvwrvDD-Q3Hv5J0fSKbE",
"alg": "RS256",
"crv": "P-384",
"kid": "key-1",
"kty": "RSA",
"use": "sig"
}
],
"description": "string",
"publishedAt": "2018-10-30T07:06:22Z",
"allowedScopes": [
"string"
],
"clientSecrets": [
{
"hint": "string",
"createdAt": "2025-12-03T14:59:46.331Z",
"createdBy": "string"
}
],
"createdByType": "string",
"connectionConfig": {
"consentMethod": "required"
},
"allowedGrantTypes": [
"client_credentials"
],
"allowedAuthMethods": [
"client_secret"
],
"clientId": "string",
"clientSecret": "string",
"redirectUris": [
"string"
],
"allowedOrigins": [
"string"
]
}

Get an OAuth client

Retrieves the specified OAuth client.

Facts

Rate limit Tier 1 (1000 requests per minute)

Path Parameters

  • id string
    Required

    The unique identifier for the OAuth client

Responses

200

OK

  • application/json object
    One of:
    • OAuthClientAdminReadResponse object

      Response schema for reading an OAuth client as an admin user

      Show OAuthClientAdminReadResponse properties
      • jwksUri string

        URI of the JSON Web Key Set (JWKS) for the client

      • clientId string
        Required

        Client application id

      • publicKeys array of objects

        List of public keys for JWT authentication

        Show publicKeys properties
        • e string

          Exponent for RSA keys

        • n string

          Modulus for RSA keys

        • x string

          X coordinate for EC keys

        • y string

          Y coordinate for EC keys

        • alg string
          Required

          Algorithm intended for use with the key

          Can be one of: "RS256""RS512""ES384"

        • crv string

          Curve for EC keys

        • kid string
          Required

          Key ID

        • kty string
          Required

          Key type (e.g., RSA, EC)

          Can be one of: "RSA""EC"

        • use string
          Required

          Intended use of the key (typically "sig" for signature)

          Can be one of: "sig"

      • redirectUris array of strings

        List of allowed redirect URIs for login

      • clientSecrets array of objects

        Hints of any client application secrets

        Show clientSecrets properties
        • hint string
          Required

          Hint of a client application secret

        • createdAt string

          The timestamp for when the client-secret record was created.

        • createdBy string

          The identifier for the user that created the client-secret record.

      • allowedOrigins array of strings

        List of allowed origins for client

      • allowedAuthMethods array of strings

        List of allowed authentication methods for the client

        Values may be any of: "client_secret""private_key_jwt"

      • appType string
        Required

        Application type

        Can be one of: "web""native""spa""anonymous-embed"

      • logoUri string

        URI for logo of client

      • clientUri string

        URI for homepage of client

      • createdAt string
        Required

        The timestamp for when the oauth-clients record was created.

      • deletedAt string

        The timestamp for when the oauth-clients record was deleted.

      • updatedAt string

        The timestamp for when the oauth-clients record was updated.

      • clientName string
        Required

        Client application name

      • disableTag string

        Is set if client disabled

      • description string

        Client description

      • publishedAt string

        The timestamp which is set, if the client is published.

      • allowedScopes array of strings

        List of allowed scopes for this client. For a full list of scopes see qlik.dev/authenticate/oauth/scopes/.

      • createdByType string

        The type of caller that created this client. Possible values are user, service, and dcr for Dynamic Client Registration.

      • connectionConfig object

        Optional settings for configuring the client connection.

        Show connectionConfig properties
        • consentMethod string

          Specifies the consent method for the connection.

          Can be one of: "required""trusted"

      • allowedGrantTypes array of strings

        Allowed grant types, only for use with appType: 'web'

        Values may be any of: "client_credentials""urn:qlik:oauth:user-impersonation"

    • OAuthClientReadResponse object

      Response schema for reading an OAuth client

      Show OAuthClientReadResponse properties
      • clientId string
        Required

        Client application id

      • appType string
        Required

        Application type

        Can be one of: "web""native""spa""anonymous-embed"

      • jwksUri string

        URI of the JSON Web Key Set (JWKS) for the client

      • logoUri string

        URI for logo of client

      • clientUri string

        URI for homepage of client

      • createdAt string
        Required

        The timestamp for when the oauth-clients record was created.

      • deletedAt string

        The timestamp for when the oauth-clients record was deleted.

      • updatedAt string

        The timestamp for when the oauth-clients record was updated.

      • clientName string
        Required

        Client application name

      • disableTag string

        Is set if client disabled

      • publicKeys array of objects

        List of public keys for JWT authentication

        Show publicKeys properties
        • e string

          Exponent for RSA keys

        • n string

          Modulus for RSA keys

        • x string

          X coordinate for EC keys

        • y string

          Y coordinate for EC keys

        • alg string
          Required

          Algorithm intended for use with the key

          Can be one of: "RS256""RS512""ES384"

        • crv string

          Curve for EC keys

        • kid string
          Required

          Key ID

        • kty string
          Required

          Key type (e.g., RSA, EC)

          Can be one of: "RSA""EC"

        • use string
          Required

          Intended use of the key (typically "sig" for signature)

          Can be one of: "sig"

      • description string

        Client description

      • publishedAt string

        The timestamp which is set, if the client is published.

      • allowedScopes array of strings

        List of allowed scopes for this client. For a full list of scopes see qlik.dev/authenticate/oauth/scopes/.

      • clientSecrets array of objects

        Hints of any client application secrets

        Show clientSecrets properties
        • hint string
          Required

          Hint of a client application secret

        • createdAt string

          The timestamp for when the client-secret record was created.

        • createdBy string

          The identifier for the user that created the client-secret record.

      • createdByType string

        The type of caller that created this client. Possible values are user, service, and dcr for Dynamic Client Registration.

      • connectionConfig object

        Optional settings for configuring the client connection.

        Show connectionConfig properties
        • consentMethod string

          Specifies the consent method for the connection.

          Can be one of: "required""trusted"

      • allowedGrantTypes array of strings

        Allowed grant types, only for use with appType: 'web'

        Values may be any of: "client_credentials""urn:qlik:oauth:user-impersonation"

      • allowedAuthMethods array of strings

        List of allowed authentication methods for the client

        Values may be any of: "client_secret""private_key_jwt"

400

Bad Request

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

404

Not Found

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

GET /api/v1/oauth-clients/{id}
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.getOAuthClient('string')
qlik oauth-client get 'string'
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients/{id}" \
-H "Authorization: Bearer <access_token>"

Example Response

{
"appType": "web",
"jwksUri": "https://example.com/.well-known/jwks.json",
"logoUri": "string",
"clientUri": "string",
"createdAt": "2018-10-30T07:06:22Z",
"deletedAt": "2018-10-30T07:06:22Z",
"updatedAt": "2018-10-30T07:06:22Z",
"clientName": "string",
"disableTag": "string",
"publicKeys": [
{
"e": "AQAB",
"n": "0vx7agoebGcQSuuPiLJXZptN9nndrQmbXEps2aiAFbWhM78LhWx",
"x": "WKn-ZIGevcwGIyyrzFoZNBdaq9_TsqzGl96oc0CWuis",
"y": "y77t-RvAHRKTsSGdIYUfweuOvwrvDD-Q3Hv5J0fSKbE",
"alg": "RS256",
"crv": "P-384",
"kid": "key-1",
"kty": "RSA",
"use": "sig"
}
],
"description": "string",
"publishedAt": "2018-10-30T07:06:22Z",
"allowedScopes": [
"string"
],
"clientSecrets": [
{
"hint": "string",
"createdAt": "2018-10-30T07:06:22Z",
"createdBy": "string"
}
],
"createdByType": "string",
"connectionConfig": {
"consentMethod": "required"
},
"allowedGrantTypes": [
"client_credentials"
],
"allowedAuthMethods": [
"client_secret"
],
"clientId": "string",
"redirectUris": [
"string"
],
"allowedOrigins": [
"string"
]
}

Update an OAuth client

Updates the specified OAuth client. Returns 202 Accepted with a client secret in the response body if a client secret is generated during the update (e.g., when adding client_secret to allowedAuthMethods). Otherwise returns 204 No Content.

Facts

Rate limit Tier 2 (100 requests per minute)

Path Parameters

  • id string
    Required

    The unique identifier for the OAuth client

Request Body

Required
  • application/json array of objects

    A JSON Patch document as defined in http://tools.ietf.org/html/rfc6902

    Show application/json properties
    • op string
      Required

      The operation to be performed

      Can be one of: "add""remove""replace"

    • path string
      Required

      The path for the given resource field to patch

      Can be one of: "/allowedOrigins""/clientName""/clientUri""/description""/logoUri""/redirectUris""/allowedScopes""/allowedGrantTypes""/publicKeys""/allowedAuthMethods""/jwksUri"

    • value string|array

      The value to be used for this operation.

      One of:
      • string
      • array of strings

Responses

202

Accepted - Client secret was generated

  • application/json object

    Response schema for PATCH /oauth-clients when a client secret is generated

    Show application/json properties
    • clientSecret string
      Required

      The generated client application secret

204

No Content

400

Bad Request

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

404

Not Found

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

PATCH /api/v1/oauth-clients/{id}
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.patchOAuthClient(
'string',
[
{
op: 'add',
path: '/allowedOrigins',
value: 'string',
},
],
)
qlik oauth-client patch 'string' \
--op 'add' \
--path '/allowedOrigins'
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients/{id}" \
-X PATCH \
-H "Content-type: application/json" \
-H "Authorization: Bearer <access_token>" \
-d '[{"op":"add","path":"/allowedOrigins","value":"string"}]'

Example Response

{
"clientSecret": "string"
}

Delete an OAuth client

Delete the specified OAuth client.

Facts

Rate limit Tier 2 (100 requests per minute)

Header Parameters

  • qlik-confirm-delete string
    Required

    A confirmation string that should match the id of the oauth-client resource to be deleted

Path Parameters

  • id string
    Required

    The unique identifier for the OAuth client

Responses

204

No Content

400

Bad Request

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

404

Not Found

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

DELETE /api/v1/oauth-clients/{id}
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.deleteOAuthClient(
'string',
)
qlik oauth-client rm 'string'
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients/{id}" \
-X DELETE \
-H "qlik-confirm-delete: string" \
-H "Authorization: Bearer <access_token>"

Publish an OAuth client

Publishes the specified OAuth client. By default, OAuth clients are bound to the tenant that created it. Publishing shares the client and makes it available to all other tenants within a region. Third-party applications connecting to Qlik Cloud can then have the same client ID for all Qlik Cloud tenants.

Facts

Rate limit Tier 2 (100 requests per minute)

Path Parameters

  • id string
    Required

    The unique identifier for the OAuth client

Responses

201

Created

  • application/json object

    Response schema for successfully publishing an OAuth client

    Show application/json properties
    • publishedAt string
      Required

      The timestamp which is set, if the client is published.

400

Bad Request

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

404

Not Found

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

POST /api/v1/oauth-clients/{id}/actions/publish
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.publishOAuthClient(
'string',
)
qlik oauth-client publish 'string'
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients/{id}/actions/publish" \
-X POST \
-H "Authorization: Bearer <access_token>"

Example Response

{
"publishedAt": "2018-10-30T07:06:22Z"
}

Create an OAuth client secret

Create a new client secret for the specified OAuth client. An OAuth client can have a maximum of 5 client secrets at one time.

Facts

Rate limit Tier 2 (100 requests per minute)

Path Parameters

  • id string
    Required

    The unique identifier for the OAuth client

Responses

201

Created

  • application/json object

    Response schema for creating an OAuth client application secret

    Show application/json properties
    • hint string
      Required

      Client application hint

    • clientId string
      Required

      Client application id

    • createdAt string

      The timestamp for when the client-secret record was created.

    • createdBy string

      The identifier for the user that created the client-secret record.

    • clientSecret string
      Required

      Client application secret

400

Bad Request

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

404

Not Found

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

409

The max number of client secrets is 5

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

POST /api/v1/oauth-clients/{id}/client-secrets
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.createOAuthClientSecret(
'string',
)
qlik oauth-client client-secret create \
--oauth-clientId 'string'
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients/{id}/client-secrets" \
-X POST \
-H "Authorization: Bearer <access_token>"

Example Response

{
"hint": "string",
"clientId": "string",
"createdAt": "2018-10-30T07:06:22Z",
"createdBy": "string",
"clientSecret": "string"
}

Delete an OAuth client secret

Deletes a specific client secret for an OAuth client.

Facts

Rate limit Tier 2 (100 requests per minute)

Path Parameters

  • hint string
    Required

    The unique identifier for the OAuth secret

  • id string
    Required

    The unique identifier for the OAuth client

Responses

204

No Content

400

Bad Request

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

404

Not Found

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

DELETE /api/v1/oauth-clients/{id}/client-secrets/{hint}
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.deleteOAuthClientSecret(
'string',
'string',
)
qlik oauth-client client-secret rm 'string' \
--oauth-clientId 'string'
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients/{id}/client-secrets/{hint}" \
-X DELETE \
-H "Authorization: Bearer <access_token>"

Get connection config for an OAuth client

Get configuration for consent method and status.

Facts

Rate limit Tier 1 (1000 requests per minute)

Path Parameters

  • id string
    Required

    The unique identifier for an OAuth client

Responses

200

OK

  • application/json object

    Response schema for reading a connection config

    Show application/json properties
    • status string

      Status

    • consentMethod string
      Required

      Consent method

    • deletedByOwner boolean

      OAuth client has been deleted by owning tenant, only applies for published clients.

400

Bad Request

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

404

Not Found

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

GET /api/v1/oauth-clients/{id}/connection-configs/me
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.getOAuthClientConnectionConfig(
'string',
)
qlik oauth-client connection-config ls 'string'
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients/{id}/connection-configs/me" \
-H "Authorization: Bearer <access_token>"

Example Response

{
"status": "string",
"consentMethod": "string",
"deletedByOwner": true
}

Update connection config for an OAuth client

Updates the consent method for the specified OAuth client.

Facts

Rate limit Tier 2 (100 requests per minute)

Path Parameters

  • id string
    Required

    The unique identifier for the OAuth client

Request Body

Required
  • application/json array of objects

    A JSON Patch document as defined in http://tools.ietf.org/html/rfc6902

    One of:
    • object

      Patch the consent method. Only replace is supported.

      Show properties
      • op string
        Required

        Can be one of: "replace"

      • path string
        Required

        Can be one of: "/consentMethod"

      • value string
        Required

        Can be one of: "required""trusted"

Responses

204

No Content

400

Bad Request

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

404

Not Found

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

PATCH /api/v1/oauth-clients/{id}/connection-configs/me
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.patchOAuthClientConnectionConfig(
'string',
[
{
op: 'replace',
path: '/consentMethod',
value: 'required',
},
],
)
qlik oauth-client connection-config patch 'string' \
--op 'replace' \
--path '/consentMethod' \
--value 'required'
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients/{id}/connection-configs/me" \
-X PATCH \
-H "Content-type: application/json" \
-H "Authorization: Bearer <access_token>" \
-d '[{"op":"replace","path":"/consentMethod","value":"required"}]'

Delete connection config for an OAuth client

Deletes the connection config for the calling tenant, related to the supplied client id.

Facts

Rate limit Tier 2 (100 requests per minute)

Path Parameters

  • id string
    Required

    The unique identifier for the OAuth client

Responses

204

No Content

400

Bad Request

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

401

Unauthorized

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

403

Forbidden

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

404

Not Found

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

500

Internal Server Error

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

503

Service Unavailable

  • application/json object
    Show application/json properties
    • errors array of objects
      Show errors properties
      • code string
        Required

        The unique code for the error

      • title string
        Required

        A summary of the error

      • detail string

        Additional details about the error

DELETE /api/v1/oauth-clients/{id}/connection-configs/me
import { createQlikApi } from '@qlik/api'
const qlik = createQlikApi({
hostConfig: {
host: 'https://{tenant}.{region}.qlikcloud.com',
apiKey: '<access-token>',
},
})
await qlik.oauthClients.deleteOAuthClientConnectionConfig(
'string',
)
qlik oauth-client connection-config rm 'string'
curl "https://{tenant}.{region}.qlikcloud.com/api/v1/oauth-clients/{id}/connection-configs/me" \
-X DELETE \
-H "Authorization: Bearer <access_token>"